pub enum ClassField {
Field(DCField),
Atomic(DCAtomicField),
Molecular(DCMolecularField),
}Expand description
Enumerator representing the 3 types of fields that inherit DC Field, which can legally be declared within a Distributed Class.
Plain DC Fields represent a property, or member, of a structure or class. DC fields have a data type assigned to them.
DC Atomic Fields represent a method of a Distributed Class, which is always implemented as a remote procedure call (RPC). Unlike attribute fields, atomic fields cannot be declared within structs.
DC Molecular Fields represent a collection of one or more DC Atomic Fields as one field under one identifier. The parameters of a molecular field are the parameters of all the fields it represents, joined together in the order in which they were declared when the molecular field was declared.
Variants